'''
Date         : 2023-01-17 10:33:06
Author       : BDFD,bdfd2005@gmail.com
Github       : https://github.com/bdfd
LastEditTime : 2023-01-17 10:37:14
LastEditors  : BDFD
Description  : 
FilePath     : \execdata\data_conv.py
Copyright (c) 2023 by BDFD, All Rights Reserved. 
'''
def convint(str):
    result = ''
    result = int(str)
    return result

def convfloat(str):
    result = ''
    result = float(str)
    return result